@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+# Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
 # Copyright (C) 2005 Julien Louis <ptitlouis@sysif.net>
 # Copyright (C) 2005-2006 Emmanuel Bouthenot <kolter@openics.org>
 #
@@ -17,15 +17,15 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+# along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
 #
 
 ###
 ### common stuff
 ###
 
-DIR=$(cd $(dirname "$0"); pwd)
-cd $DIR
+DIR=$(cd "$(dirname "$0")" || exit 1; pwd)
+cd "$DIR" || exit 1
 
 AUTOGEN_LOG=autogen.log
 
@@ -41,9 +41,8 @@ err ()
 
 run ()
 {
-    echo -n "Running \"$@\"..."
-    eval $@ >$AUTOGEN_LOG 2>&1
-    if [ $? = 0 ] ; then
+    printf "Running \"%s\"..." "$@"
+    if eval "$@" >$AUTOGEN_LOG 2>&1 ; then
         echo " OK"
     else
         echo " FAILED"
