@@ -17,27 +17,33 @@
 #
 
 """
-Documentation generator for WeeChat: build include files with commands,
-options, infos, infolists, hdata and completions for WeeChat core and
-plugins.
+Documentation generator for WeeChat: build include files with:
 
-Instructions to build config files yourself in WeeChat directories (replace
-all paths with your path to WeeChat):
-    1.  run WeeChat and load this script, with following command:
-          /python load ~/src/weechat/doc/docgen.py
-    2.  change path to build in your doc/ directory:
-          /set plugins.var.python.docgen.path "~/src/weechat/doc"
-    3.  run docgen command:
-          /docgen
-Note: it is recommended to load only this script when building doc.
-Files should be in ~/src/weechat/doc/xx/autogen/ (where xx is language).
+- commands
+- config options
+- default aliases
+- IRC colors
+- infos
+- infos hashtable
+- infolists
+- hdata
+- completions
+- URL options
+- plugins priority.
+
+Instructions to build config files yourself in WeeChat directories
+(replace "path" with the path to the docgen.py script in WeeChat repository):
+
+  weechat -t -r "/python load /path/docgen.py;/docgen;/quit"
+
+Output files are in /path/xx/autogen/ (where xx is language).
 """
 
 from __future__ import print_function
 
 SCRIPT_NAME = 'docgen'
 SCRIPT_AUTHOR = 'Sébastien Helleu <flashcode@flashtux.org>'
-SCRIPT_VERSION = '0.1'
+SCRIPT_VERSION = '0.2'
 SCRIPT_LICENSE = 'GPL3'
 SCRIPT_DESC = 'Documentation generator for WeeChat'
 
@@ -51,7 +57,6 @@ try:
     import hashlib
     import os
     import re
-    import sys
     from collections import defaultdict
     from operator import itemgetter
 except ImportError as message:
@@ -65,19 +70,15 @@ except ImportError:
     print('Get WeeChat now at: https://weechat.org/')
     IMPORT_OK = False
 
-# default path where doc files will be written (should be doc/ in sources
-# package tree)
-# path must have subdirectories with languages and autogen directory:
-#      path
-#       |-- en
-#       |   |-- autogen
-#       |-- fr
-#       |   |-- autogen
-#       ...
-DEFAULT_PATH = '~/src/weechat/doc'
-
 # list of locales for which we want to build doc files to include
-LOCALE_LIST = ('en_US', 'fr_FR', 'it_IT', 'de_DE', 'ja_JP', 'pl_PL')
+LOCALE_LIST = (
+    'de_DE',
+    'en_US',
+    'fr_FR',
+    'it_IT',
+    'ja_JP',
+    'pl_PL',
+)
 
 # all commands/options/.. of following plugins will produce a file
 # non-listed plugins will be ignored
@@ -120,7 +121,6 @@ IGNORE_OPTIONS = (
     r'irc\.ctcp\..*',
     r'irc\.ignore\..*',
     r'irc\.server\..*',
-    r'jabber\.server\..*',
     r'logger\.level\..*',
     r'logger\.mask\..*',
     r'relay\.port\..*',
@@ -137,11 +137,19 @@ IGNORE_OPTIONS = (
 # completions to ignore
 IGNORE_COMPLETIONS_ITEMS = (
     'docgen.*',
-    'jabber.*',
-    'weeget.*',
 )
 
 
+def sha256_file(filename, default=None):
+    """Return SHA256 checksum of a file."""
+    try:
+        with open(filename, 'rb') as _file:
+            checksum = hashlib.sha256(_file.read()).hexdigest()
+    except IOError:
+        checksum = default
+    return checksum
+
+
 class AutogenDoc(object):
     """A class to write auto-generated doc files."""
 
@@ -159,29 +167,14 @@ class AutogenDoc(object):
         """Write a line in auto-generated doc file."""
         self._file.write(string)
 
-    @staticmethod
-    def sha256_file(filename, default):
-        """
-        Return SHA256 checksum of a file, "default" if file is not found.
-        """
-        try:
-            with open(filename, 'r') as _file:
-                content = _file.read()
-                if sys.version_info >= (3, ):
-                    content = content.encode('utf-8')
-                checksum = hashlib.sha256(content).hexdigest()
-        except IOError:
-            checksum = default
-        return checksum
-
     def update(self, obj_name, num_files, num_files_updated):
         """Update doc file if needed (if content has changed)."""
         # close temp file
         self._file.close()
-        shaold = AutogenDoc.sha256_file(self.filename, 'old')
-        shanew = AutogenDoc.sha256_file(self.filename_tmp, 'new')
+        sha_old = sha256_file(self.filename, 'old')
+        sha_new = sha256_file(self.filename_tmp, 'new')
         # compare checksums
-        if shaold != shanew:
+        if sha_old != sha_new:
             # update doc file
             if os.path.exists(self.filename):
                 os.unlink(self.filename)
@@ -450,6 +443,15 @@ def get_plugins_priority():
     return plugins_priority
 
 
+def print_counters(label, files, updated):
+    """Print a line with counters."""
+    color = weechat.color('*lightred') if updated > 0 else ''
+    weechat.prnt('',
+                 'docgen: {0}: {1} files, {2}{3}{4} updated'
+                 ''.format(label, files, color, updated,
+                           weechat.color('reset')))
+
+
 # pylint: disable=too-many-locals, too-many-branches, too-many-statements
 # pylint: disable=too-many-nested-blocks
 def docgen_cmd_cb(data, buf, args):
@@ -457,7 +459,7 @@ def docgen_cmd_cb(data, buf, args):
     if args:
         locales = args.split(' ')
     else:
-        locales = LOCALE_LIST
+        locales = sorted(LOCALE_LIST)
     commands = get_commands()
     options = get_options()
     infos = get_infos()
@@ -470,11 +472,6 @@ def docgen_cmd_cb(data, buf, args):
     irc_colors = get_irc_colors()
     plugins_priority = get_plugins_priority()
 
-    # get path and replace ~ by home if needed
-    path = weechat.config_get_plugin('path')
-    if path.startswith('~'):
-        path = os.environ['HOME'] + path[1:]
-
     # write to doc files, by locale
     num_files = defaultdict(int)
     num_files_updated = defaultdict(int)
@@ -483,6 +480,8 @@ def docgen_cmd_cb(data, buf, args):
     translate = lambda s: (s and _(s)) or s
     escape = lambda s: s.replace('|', '\\|')
 
+    weechat.prnt('', '-' * 40)
+
     for locale in locales:
         for key in num_files:
             if key != 'total2':
@@ -493,7 +492,9 @@ def docgen_cmd_cb(data, buf, args):
                                     languages=[locale + '.UTF-8'],
                                     fallback=True)
         trans.install()
-        directory = path + '/' + locale[0:2] + '/autogen'
+        directory = os.path.join(os.path.dirname(data),
+                                 locale[0:2],
+                                 'autogen')
         if not os.path.isdir(directory):
             weechat.prnt('',
                          '{0}docgen error: directory "{1}" does not exist'
@@ -721,7 +722,7 @@ def docgen_cmd_cb(data, buf, args):
         doc.write('|===\n')
         doc.update('completions', num_files, num_files_updated)
 
-        # write url options
+        # write URL options
         doc = AutogenDoc(directory, 'plugin_api', 'url_options')
         doc.write('[width="100%",cols="2,^1,7",options="header"]\n')
         doc.write('|===\n')
@@ -748,14 +749,15 @@ def docgen_cmd_cb(data, buf, args):
         doc.update('plugins_priority', num_files, num_files_updated)
 
         # write counters
-        weechat.prnt('',
-                     'docgen: {0}: {1} files, {2} updated'
-                     ''.format(locale,
-                               num_files['total1'],
-                               num_files_updated['total1']))
-    weechat.prnt('',
-                 'docgen: total: {0} files, {1} updated'
-                 ''.format(num_files['total2'], num_files_updated['total2']))
+        print_counters(locale, num_files['total1'],
+                       num_files_updated['total1'])
+
+    weechat.prnt('', ' -' * 20)
+
+    print_counters('total', num_files['total2'], num_files_updated['total2'])
+
+    weechat.prnt('', '-' * 40)
+
     return weechat.WEECHAT_RC_OK
 
 
@@ -776,8 +778,6 @@ if __name__ == '__main__' and IMPORT_OK:
                              'locales: list of locales to build (by default '
                              'build all locales)',
                              '%(docgen_locales)|%*',
-                             'docgen_cmd_cb', '')
+                             'docgen_cmd_cb', __file__)
         weechat.hook_completion('docgen_locales', 'locales for docgen',
                                 'docgen_completion_cb', '')
-        if not weechat.config_is_set_plugin('path'):
-            weechat.config_set_plugin('path', DEFAULT_PATH)
