@@ -1,3 +1,4 @@
+
 /*
  * wee-completion.c - completion for WeeChat commands
  *
@@ -36,6 +37,7 @@
 #include "weechat.h"
 #include "wee-arraylist.h"
 #include "wee-config.h"
+#include "wee-eval.h"
 #include "wee-hashtable.h"
 #include "wee-hook.h"
 #include "wee-list.h"
@@ -435,6 +437,7 @@ completion_list_add_filename_cb (const void *pointer, void *data,
     char home[3] = { '~', DIR_SEPARATOR_CHAR, '\0' };
     char *ptr_home, *pos, buf[PATH_MAX], *real_prefix, *prefix, *path_dir;
     char *path_base, *dir_name;
+    const char *pos_args;
     int length_path_base;
     DIR *dp;
     struct dirent *entry;
@@ -443,11 +446,14 @@ completion_list_add_filename_cb (const void *pointer, void *data,
     /* make C compiler happy */
     (void) pointer;
     (void) data;
-    (void) completion_item;
     (void) buffer;
 
     completion->add_space = 0;
 
+    pos_args = (completion_item) ? strchr (completion_item, ':') : NULL;
+    if (pos_args)
+        pos_args++;
+
     ptr_home = getenv ("HOME");
 
     real_prefix = NULL;
@@ -466,7 +472,18 @@ completion_list_add_filename_cb (const void *pointer, void *data,
         if (!completion->base_word[0]
             || completion->base_word[0] != DIR_SEPARATOR_CHAR)
         {
-            real_prefix = strdup (weechat_home);
+            real_prefix = NULL;
+            if (pos_args && pos_args[0])
+            {
+                real_prefix = eval_expression (pos_args, NULL, NULL, NULL);
+                if (real_prefix && !real_prefix[0])
+                {
+                    free (real_prefix);
+                    real_prefix = NULL;
+                }
+            }
+            if (!real_prefix)
+                real_prefix = strdup (weechat_home);
             prefix = strdup ("");
         }
         else
@@ -603,7 +620,7 @@ completion_list_add_commands_cb (const void *pointer, void *data,
     (void) data;
     (void) buffer;
 
-    pos = strchr (completion_item, ':');
+    pos = (completion_item) ? strchr (completion_item, ':') : NULL;
     if (pos)
         pos++;
 
@@ -974,7 +991,7 @@ completion_list_add_plugins_commands_cb (const void *pointer, void *data,
 
     if (argc > 0)
     {
-        pos = strchr (completion_item, ':');
+        pos = (completion_item) ? strchr (completion_item, ':') : NULL;
         if (pos)
             pos++;
 
@@ -1271,7 +1288,7 @@ completion_list_add_weechat_commands_cb (const void *pointer, void *data,
     (void) data;
     (void) buffer;
 
-    pos = strchr (completion_item, ':');
+    pos = (completion_item) ? strchr (completion_item, ':') : NULL;
     if (pos)
         pos++;
 
@@ -1714,7 +1731,9 @@ completion_init ()
                      N_("configuration files"),
                      &completion_list_add_config_files_cb, NULL, NULL);
     hook_completion (NULL, "filename", /* formerly "%f" */
-                     N_("filename"),
+                     N_("filename; "
+                        "optional argument: default path (evaluated, "
+                        "see /help eval)"),
                      &completion_list_add_filename_cb, NULL, NULL);
     hook_completion (NULL, "filters_names", /* formerly "%F" */
                      N_("names of filters"),
