@@ -30,6 +30,7 @@
 
 #include "weechat.h"
 #include "wee-eval.h"
+#include "wee-calc.h"
 #include "wee-config-file.h"
 #include "wee-hashtable.h"
 #include "wee-hdata.h"
@@ -38,6 +39,7 @@
 #include "wee-string.h"
 #include "wee-utf8.h"
 #include "../gui/gui-buffer.h"
+#include "../gui/gui-chat.h"
 #include "../gui/gui-color.h"
 #include "../gui/gui-window.h"
 #include "../plugins/plugin.h"
@@ -293,17 +295,22 @@ end:
  *   5. a string with max chars (format: cut:max,suffix,string or
  *      cut:+max,suffix,string) or max chars on screen
  *      (format: cutscr:max,suffix,string or cutscr:+max,suffix,string)
- *   6. a reversed string (format: rev:xxx)
+ *   6. a reversed string (format: rev:xxx) or reversed string for screen,
+ *      color codes are not reversed (format: revscr:xxx)
  *   7. a repeated string (format: repeat:count,string)
- *   8. a regex group captured (format: re:N (0.99) or re:+)
- *   9. a color (format: color:xxx)
- *  10. an info (format: info:name,arguments)
- *  11. current date/time (format: date or date:xxx)
- *  12. an environment variable (format: env:XXX)
- *  13. a ternary operator (format: if:condition?value_if_true:value_if_false)
- *  14. an option (format: file.section.option)
- *  15. a buffer local variable
- *  16. a hdata variable (format: hdata.var1.var2 or hdata[list].var1.var2
+ *   8. length of a string (format: length:xxx) or length of a string on screen
+ *      (format: lengthscr:xxx); color codes are ignored
+ *   9. a regex group captured (format: re:N (0.99) or re:+)
+ *  10. a color (format: color:xxx)
+ *  11. a modifier (format: modifier:name,data,xxx)
+ *  12. an info (format: info:name,arguments)
+ *  13. current date/time (format: date or date:xxx)
+ *  14. an environment variable (format: env:XXX)
+ *  15. a ternary operator (format: if:condition?value_if_true:value_if_false)
+ *  16. calculate result of an expression (format: calc:xxx)
+ *  17. an option (format: file.section.option)
+ *  18. a buffer local variable
+ *  19. a hdata variable (format: hdata.var1.var2 or hdata[list].var1.var2
  *                        or hdata[ptr].var1.var2)
  *
  * See /help in WeeChat for examples.
@@ -319,7 +326,7 @@ eval_replace_vars_cb (void *data, const char *text)
     struct t_gui_buffer *ptr_buffer;
     char str_value[512], *value, *pos, *pos1, *pos2, *hdata_name, *list_name;
     char *tmp, *tmp2, *info_name, *hide_char, *hidden_string, *error;
-    char *condition;
+    char *condition, *modifier_name, *modifier_data;
     const char *ptr_value, *ptr_arguments, *ptr_string;
     struct t_hdata *hdata;
     void *pointer;
@@ -453,9 +460,9 @@ eval_replace_vars_cb (void *data, const char *text)
 
     /* 6. reverse string */
     if (strncmp (text, "rev:", 4) == 0)
-    {
         return string_reverse (text + 4);
-    }
+    if (strncmp (text, "revscr:", 7) == 0)
+        return string_reverse_screen (text + 7);
 
     /* 7. repeated string */
     if (strncmp (text, "repeat:", 7) == 0)
@@ -476,7 +483,25 @@ eval_replace_vars_cb (void *data, const char *text)
         return string_repeat (pos + 1, number);
     }
 
-    /* 8. regex group captured */
+    /*
+     * 8. length of string:
+     *   length: number of chars
+     *   lengthscr: number of chars displayed on screen
+     */
+    if (strncmp (text, "length:", 7) == 0)
+    {
+        length = gui_chat_strlen (text + 7);
+        snprintf (str_value, sizeof (str_value), "%d", length);
+        return strdup (str_value);
+    }
+    if (strncmp (text, "lengthscr:", 10) == 0)
+    {
+        length = gui_chat_strlen_screen (text + 10);
+        snprintf (str_value, sizeof (str_value), "%d", length);
+        return strdup (str_value);
+    }
+
+    /* 9. regex group captured */
     if (strncmp (text, "re:", 3) == 0)
     {
         if (eval_context->regex && eval_context->regex->result)
@@ -507,7 +532,7 @@ eval_replace_vars_cb (void *data, const char *text)
         return strdup ("");
     }
 
-    /* 9. color code */
+    /* 10. color code */
     if (strncmp (text, "color:", 6) == 0)
     {
         ptr_value = gui_color_search_config (text + 6);
@@ -517,7 +542,31 @@ eval_replace_vars_cb (void *data, const char *text)
         return strdup ((ptr_value) ? ptr_value : "");
     }
 
-    /* 10. info */
+    /* 11. modifier */
+    if (strncmp (text, "modifier:", 9) == 0)
+    {
+        value = NULL;
+        ptr_arguments = strchr (text + 9, ',');
+        if (!ptr_arguments)
+            return strdup ("");
+        ptr_arguments++;
+        ptr_string = strchr (ptr_arguments, ',');
+        if (!ptr_string)
+            return strdup ("");
+        ptr_string++;
+        modifier_name = string_strndup (text + 9, ptr_arguments - 1 - text - 9);
+        modifier_data = string_strndup (ptr_arguments,
+                                        ptr_string - 1 - ptr_arguments);
+        value = hook_modifier_exec (NULL, modifier_name, modifier_data,
+                                    ptr_string);
+        if (modifier_name)
+            free (modifier_name);
+        if (modifier_data)
+            free (modifier_data);
+        return (value) ? value : strdup ("");
+    }
+
+    /* 12. info */
     if (strncmp (text, "info:", 5) == 0)
     {
         value = NULL;
@@ -537,7 +586,7 @@ eval_replace_vars_cb (void *data, const char *text)
         return (value) ? value : strdup ("");
     }
 
-    /* 11. current date/time */
+    /* 13. current date/time */
     if ((strncmp (text, "date", 4) == 0) && (!text[4] || (text[4] == ':')))
     {
         date = time (NULL);
@@ -550,7 +599,7 @@ eval_replace_vars_cb (void *data, const char *text)
         return strdup ((rc > 0) ? str_value : "");
     }
 
-    /* 12. environment variable */
+    /* 14. environment variable */
     if (strncmp (text, "env:", 4) == 0)
     {
         ptr_value = getenv (text + 4);
@@ -558,7 +607,7 @@ eval_replace_vars_cb (void *data, const char *text)
             return strdup (ptr_value);
     }
 
-    /* 13: ternary operator: if:condition?value_if_true:value_if_false */
+    /* 15: ternary operator: if:condition?value_if_true:value_if_false */
     if (strncmp (text, "if:", 3) == 0)
     {
         value = NULL;
@@ -625,7 +674,16 @@ eval_replace_vars_cb (void *data, const char *text)
         return (value) ? value : strdup ("");
     }
 
-    /* 14. option: if found, return this value */
+    /*
+     * 16. calculate the result of an expression
+     * (with number, operators and parentheses)
+     */
+    if (strncmp (text, "calc:", 5) == 0)
+    {
+        return calc_expression (text + 5);
+    }
+
+    /* 17. option: if found, return this value */
     if (strncmp (text, "sec.data.", 9) == 0)
     {
         ptr_value = hashtable_get (secure_hashtable_data, text + 9);
@@ -658,7 +716,7 @@ eval_replace_vars_cb (void *data, const char *text)
         }
     }
 
-    /* 15. local variable in buffer */
+    /* 18. local variable in buffer */
     ptr_buffer = hashtable_get (eval_context->pointers, "buffer");
     if (ptr_buffer)
     {
@@ -667,7 +725,7 @@ eval_replace_vars_cb (void *data, const char *text)
             return strdup (ptr_value);
     }
 
-    /* 16. hdata */
+    /* 19. hdata */
     value = NULL;
     hdata_name = NULL;
     list_name = NULL;
