@@ -1,7 +1,7 @@
 /*
  * wee-list.c - sorted lists
  *
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -349,6 +349,19 @@ weelist_string (struct t_weelist_item *item)
     return NULL;
 }
 
+/*
+ * Gets user data pointer to item data.
+ */
+
+void *
+weelist_user_data (struct t_weelist_item *item)
+{
+    if (item)
+        return item->user_data;
+
+    return NULL;
+}
+
 /*
  * Gets size of list.
  */
