@@ -40,6 +40,7 @@ extern char *string_strndup (const char *string, int length);
 extern char *string_cut (const char *string, int length, int count_suffix,
                          int screen, const char *cut_suffix);
 extern char *string_reverse (const char *string);
+extern char *string_reverse_screen (const char *string);
 extern char *string_repeat (const char *string, int count);
 extern void string_tolower (char *string);
 extern void string_toupper (char *string);
@@ -57,6 +58,8 @@ extern int string_strcmp_ignore_chars (const char *string1,
 extern const char *string_strcasestr (const char *string, const char *search);
 extern int string_match (const char *string, const char *mask,
                          int case_sensitive);
+extern int string_match_list (const char *string, const char **masks,
+                              int case_sensitive);
 extern char *string_replace (const char *string, const char *search,
                              const char *replace);
 extern char *string_expand_home (const char *path);
@@ -85,10 +88,11 @@ extern char *string_replace_regex (const char *string, void *regex,
                                    char *(*callback)(void *data, const char *text),
                                    void *callback_data);
 extern char **string_split (const char *string, const char *separators,
-                            int keep_eol, int num_items_max, int *num_items);
+                            const char *strip_items, int flags,
+                            int num_items_max, int *num_items);
 extern char **string_split_shared (const char *string, const char *separators,
-                                   int keep_eol, int num_items_max,
-                                   int *num_items);
+                                   const char *strip_items, int flags,
+                                   int num_items_max, int *num_items);
 extern char **string_split_shell (const char *string, int *num_items);
 extern void string_free_split (char **split_string);
 extern void string_free_split_shared (char **split_string);
