@@ -1,7 +1,7 @@
 /*
  * gui-curses-chat.c - chat display functions for Curses GUI
  *
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -533,7 +533,10 @@ gui_chat_display_word (struct t_gui_window *window,
                 }
             }
             if (window->win_chat_cursor_y < window->coords_size)
+            {
+                window->coords[window->win_chat_cursor_y].line = line;
                 window->coords[window->win_chat_cursor_y].data = (char *)word + (ptr_data - data);
+            }
         }
 
         chars_to_display = gui_chat_strlen_screen (ptr_data);
@@ -681,6 +684,33 @@ gui_chat_display_day_changed (struct t_gui_window *window,
         free (message_with_color);
 }
 
+/*
+ * Checks if time on line is the same as time on previous line.
+ *
+ * Returns:
+ *   1: time is same as time on previous line
+ *   0: time is different from time on previous line
+ */
+
+int
+gui_chat_line_time_is_same_as_previous (struct t_gui_line *line)
+{
+    struct t_gui_line *prev_line;
+
+    /* previous line is not found => display standard time */
+    prev_line = gui_line_get_prev_displayed (line);
+    if (!prev_line)
+        return 0;
+
+    /* previous line has no time => display standard time */
+    if (!line->data->str_time || !prev_line->data->str_time)
+        return 0;
+
+    /* time can be hidden/replaced if times are equal */
+    return (strcmp (line->data->str_time, prev_line->data->str_time) == 0) ?
+        1 : 0;
+}
+
 /*
  * Displays time, buffer name (for merged buffers) and prefix for a line.
  */
@@ -719,12 +749,49 @@ gui_chat_display_time_to_prefix (struct t_gui_window *window,
     {
         if (window->win_chat_cursor_y < window->coords_size)
             window->coords[window->win_chat_cursor_y].time_x1 = window->win_chat_cursor_x;
-        gui_chat_display_word (window, line, line->data->str_time,
-                               NULL, 1, num_lines, count,
-                               pre_lines_displayed, lines_displayed,
-                               simulate,
-                               CONFIG_BOOLEAN(config_look_color_inactive_time),
-                               0);
+
+        if (CONFIG_STRING(config_look_buffer_time_same)
+            && CONFIG_STRING(config_look_buffer_time_same)[0]
+            && gui_chat_line_time_is_same_as_previous (line))
+        {
+            length_allowed = gui_chat_time_length;
+            num_spaces = length_allowed - gui_chat_strlen_screen (
+                config_buffer_time_same_evaluated);
+            gui_chat_display_word (
+                window, line, config_buffer_time_same_evaluated,
+                (num_spaces < 0) ?
+                config_buffer_time_same_evaluated +
+                gui_chat_string_real_pos (config_buffer_time_same_evaluated,
+                                          length_allowed,
+                                          1) :
+                NULL,
+                1, num_lines, count,
+                pre_lines_displayed, lines_displayed,
+                simulate,
+                CONFIG_BOOLEAN(config_look_color_inactive_time),
+                0);
+            for (i = 0; i < num_spaces; i++)
+            {
+                gui_chat_display_word (
+                    window, line, str_space,
+                    NULL, 1, num_lines, count,
+                    pre_lines_displayed, lines_displayed,
+                    simulate,
+                    CONFIG_BOOLEAN(config_look_color_inactive_time),
+                    0);
+            }
+        }
+        else
+        {
+            gui_chat_display_word (
+                window, line, line->data->str_time,
+                NULL, 1, num_lines, count,
+                pre_lines_displayed, lines_displayed,
+                simulate,
+                CONFIG_BOOLEAN(config_look_color_inactive_time),
+                0);
+        }
+
         if (window->win_chat_cursor_y < window->coords_size)
             window->coords[window->win_chat_cursor_y].time_x2 = window->win_chat_cursor_x - 1;
 
@@ -1325,7 +1392,6 @@ gui_chat_display_line (struct t_gui_window *window, struct t_gui_line *line,
     {
         if (window->win_chat_cursor_y < window->coords_size)
             window->coords[window->win_chat_cursor_y].data = line->data->message;
-        window->coords_x_message = window->win_chat_cursor_x;
     }
 
     /* reset color & style for a new line */
@@ -1989,8 +2055,17 @@ gui_chat_draw_bare (struct t_gui_window *window)
     {
         /* display from top to bottom (starting with "start_line") */
         y = 0;
-        ptr_line = (window->scroll->start_line) ?
-            window->scroll->start_line : gui_line_get_first_displayed (window->buffer);
+        if (window->scroll->start_line)
+        {
+            ptr_line = window->scroll->start_line;
+            window->scroll->first_line_displayed =
+                (ptr_line == gui_line_get_first_displayed (window->buffer));
+        }
+        else
+        {
+            ptr_line = gui_line_get_first_displayed (window->buffer);
+            window->scroll->first_line_displayed = 1;
+        }
         while (ptr_line && (y < gui_term_lines))
         {
             line = gui_chat_get_bare_line (ptr_line);
@@ -2027,6 +2102,8 @@ gui_chat_draw_bare (struct t_gui_window *window)
             free (line);
             ptr_line = gui_line_get_prev_displayed (ptr_line);
         }
+        window->scroll->first_line_displayed =
+            (ptr_line == gui_line_get_first_displayed (window->buffer));
     }
 
     /*
