@@ -115,7 +115,7 @@ int gui_color_timer = 0;                      /* timer in seconds           */
 /*
  * Searches for a color by name.
  *
- * Return index of color in WeeChat colors table, -1 if not found.
+ * Returns index of color in WeeChat colors table, -1 if not found.
  */
 
 int
@@ -133,12 +133,33 @@ gui_color_search (const char *color_name)
     return -1;
 }
 
+/*
+ * Searches for a color by index.
+ *
+ * Returns name of color in WeeChat colors table, NULL if not found.
+ */
+
+const char *
+gui_color_search_index (int index)
+{
+    int i;
+
+    for (i = 0; gui_weechat_colors[i].string; i++)
+    {
+        if (i == index)
+            return gui_weechat_colors[i].string;
+    }
+
+    /* color not found */
+    return NULL;
+}
+
 /*
  * Get Curses attributes corresponding to extended attributes flags in a color.
  */
 
 int
-gui_color_get_extended_attrs (int color)
+gui_color_get_gui_attrs (int color)
 {
     int attributes;
 
@@ -156,6 +177,29 @@ gui_color_get_extended_attrs (int color)
     return attributes;
 }
 
+/*
+ * Get extended flags corresponding to Curses attributes in a color.
+ */
+
+int
+gui_color_get_extended_flags (int attrs)
+{
+    int flags;
+
+    flags = 0;
+
+    if (attrs & A_BOLD)
+        flags |= GUI_COLOR_EXTENDED_BOLD_FLAG;
+    if (attrs & A_REVERSE)
+        flags |= GUI_COLOR_EXTENDED_REVERSE_FLAG;
+    if (attrs & A_ITALIC)
+        flags |= GUI_COLOR_EXTENDED_ITALIC_FLAG;
+    if (attrs & A_UNDERLINE)
+        flags |= GUI_COLOR_EXTENDED_UNDERLINE_FLAG;
+
+    return flags;
+}
+
 /*
  * Assigns a WeeChat color (read from configuration).
  *
@@ -285,6 +329,16 @@ gui_color_get_term_colors ()
     return gui_color_term_colors;
 }
 
+/*
+ * Gets number of color pairs supported by terminal.
+ */
+
+int
+gui_color_get_term_color_pairs ()
+{
+    return gui_color_term_color_pairs;
+}
+
 /*
  * Gets current pairs as arrays (one array for foregrounds, another for
  * backgrounds).
@@ -536,7 +590,7 @@ gui_color_build (int number, int foreground, int background)
         gui_color[number]->foreground = gui_weechat_colors[foreground & GUI_COLOR_EXTENDED_MASK].foreground;
         gui_color[number]->attributes = gui_weechat_colors[foreground & GUI_COLOR_EXTENDED_MASK].attributes;
     }
-    gui_color[number]->attributes |= gui_color_get_extended_attrs (foreground);
+    gui_color[number]->attributes |= gui_color_get_gui_attrs (foreground);
 
     /* set background */
     if (background & GUI_COLOR_EXTENDED_FLAG)
@@ -580,8 +634,9 @@ gui_color_init_vars ()
         gui_color_term_color_pairs = COLOR_PAIRS;
         gui_color_term_can_change_color = (can_change_color ()) ? 1 : 0;
 
-        gui_color_num_pairs = (gui_color_term_color_pairs >= 256) ?
-            255 : gui_color_term_color_pairs - 1;
+        /* TODO: ncurses may support 65536, but short type used for pairs supports only 32768? */
+        gui_color_num_pairs = (gui_color_term_color_pairs >= 32768) ?
+            32767 : gui_color_term_color_pairs - 1;
         size = (gui_color_term_colors + 2)
             * (gui_color_term_colors + 2)
             * sizeof (gui_color_pairs[0]);
@@ -699,7 +754,7 @@ gui_color_init_pairs_weechat ()
 void
 gui_color_display_terminal_colors ()
 {
-    int lines, line, col, color;
+    int lines, columns, line, col, color;
     char str_line[1024], str_color[64];
 
     initscr ();
@@ -727,13 +782,14 @@ gui_color_display_terminal_colors ()
         printf ("%s\n", _("Default colors:"));
         printf ("------------------------------------------------------------"
                 "--------------------\n");
-        lines = (gui_color_term_colors < 16) ? gui_color_term_colors : 16;
+        columns = 16;
+        lines = (gui_color_term_colors - 1) / columns + 1;
         for (line = 0; line < lines; line++)
         {
             str_line[0] = '\0';
-            for (col = 0; col < 16; col++)
+            for (col = 0; col < columns; col++)
             {
-                color = (col * 16) + line;
+                color = line * columns + col;
                 if (color < gui_color_term_colors)
                 {
                     snprintf (str_color, sizeof (str_color),
@@ -792,7 +848,7 @@ gui_color_info_term_colors (char *buffer, int size)
 void
 gui_color_buffer_display ()
 {
-    int y, i, lines, line, col, color, max_color, num_items;
+    int y, i, lines, columns, line, col, color, max_color, num_items;
     char str_line[1024], str_color[64], str_rgb[64], **items;
     struct t_gui_color_palette *color_palette;
 
@@ -829,17 +885,18 @@ gui_color_buffer_display ()
                            gui_color_pairs_used,
                            gui_color_num_pairs - gui_color_pairs_used);
     }
+    columns = 16;
     max_color = (gui_color_use_term_colors) ?
-        gui_color_term_colors - 1 : gui_color_num_pairs;
-    if (max_color > 255)
-        max_color = 255;
-    lines = (max_color <= 64) ? 8 : 16;
+        gui_color_term_colors - 1 : gui_color_pairs_used;
+    /* round up to nearest multiple of columns */
+    max_color = (max_color / columns) * columns + columns - 1;
+    lines = max_color / columns + 1;
     for (line = 0; line < lines; line++)
     {
         str_line[0] = '\0';
-        for (col = 0; col < 16; col++)
+        for (col = 0; col < columns; col++)
         {
-            color = (col * lines) + line;
+            color = line * columns + col;
             if (color <= max_color)
             {
                 if (color == 0)
@@ -851,13 +908,11 @@ gui_color_buffer_display ()
                          || (color <= gui_color_pairs_used))
                 {
                     snprintf (str_color, sizeof (str_color),
-                              "%c%c%05d%c%03d%c",
+                              (color <= 999) ? "%c%c%05d %03d " : "%c%c%05d%5d",
                               GUI_COLOR_COLOR_CHAR,
                               GUI_COLOR_EXTENDED_CHAR,
                               color,
-                              (color == 0) ? '<' : ' ',
-                              color,
-                              (color == 0) ? '>' : ' ');
+                              color);
                 }
                 else
                 {
@@ -936,6 +991,7 @@ gui_color_buffer_display ()
                            _("Nick colors:"));
         items = string_split (CONFIG_STRING(config_color_chat_nick_colors),
                               ",",
+                              NULL,
                               WEECHAT_STRING_SPLIT_STRIP_LEFT
                               | WEECHAT_STRING_SPLIT_STRIP_RIGHT
                               | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
@@ -1345,7 +1401,7 @@ gui_color_palette_new (int number, const char *value)
         str_alias = NULL;
         str_rgb = NULL;
 
-        items = string_split (value, ";",
+        items = string_split (value, ";", NULL,
                               WEECHAT_STRING_SPLIT_STRIP_LEFT
                               | WEECHAT_STRING_SPLIT_STRIP_RIGHT
                               | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
