@@ -181,7 +181,7 @@ gui_window_clear (WINDOW *window, int fg, int bg)
     if (!gui_init_ok)
         return;
 
-    attrs = gui_color_get_extended_attrs (fg);
+    attrs = gui_color_get_gui_attrs (fg);
 
     if ((fg > 0) && (fg & GUI_COLOR_EXTENDED_FLAG))
         fg &= GUI_COLOR_EXTENDED_MASK;
@@ -193,7 +193,13 @@ gui_window_clear (WINDOW *window, int fg, int bg)
     else
         bg = gui_weechat_colors[bg & GUI_COLOR_EXTENDED_MASK].background;
 
+#ifdef NCURSES_EXT_COLORS
+    cchar_t c;
+    setcchar (&c, L" ", attrs, gui_color_get_pair (fg, bg), NULL);
+    wbkgrndset (window, &c);
+#else
     wbkgdset (window, ' ' | COLOR_PAIR (gui_color_get_pair (fg, bg)) | attrs);
+#endif
     werase (window);
     wmove (window, 0, 0);
 }
@@ -205,9 +211,16 @@ gui_window_clear (WINDOW *window, int fg, int bg)
 void
 gui_window_clrtoeol (WINDOW *window)
 {
+#ifdef NCURSES_EXT_COLORS
+    cchar_t c;
+    setcchar (&c, L" ", A_NORMAL, gui_color_get_pair (gui_window_current_style_fg,
+                                                      gui_window_current_style_bg), NULL);
+    wbkgrndset (window, &c);
+#else
     wbkgdset (window,
               ' ' | COLOR_PAIR (gui_color_get_pair (gui_window_current_style_fg,
                                                     gui_window_current_style_bg)));
+#endif
     wclrtoeol (window);
 }
 
@@ -282,9 +295,8 @@ gui_window_reset_style (WINDOW *window, int weechat_color)
     gui_window_current_style_bg = -1;
     gui_window_current_color_attr = 0;
 
-    wattroff (window, A_ALL_ATTR);
-    wattron (window, COLOR_PAIR(gui_color_weechat_get_pair (weechat_color)) |
-             gui_color[weechat_color]->attributes);
+    wattr_set (window, gui_color[weechat_color]->attributes,
+               gui_color_weechat_get_pair (weechat_color), NULL);
 }
 
 /*
@@ -297,8 +309,8 @@ gui_window_reset_color (WINDOW *window, int weechat_color)
     gui_window_current_style_fg = gui_color[weechat_color]->foreground;
     gui_window_current_style_bg = gui_color[weechat_color]->background;
 
-    wattron (window, COLOR_PAIR(gui_color_weechat_get_pair (weechat_color)) |
-             gui_color[weechat_color]->attributes);
+    wattron (window, gui_color[weechat_color]->attributes);
+    wcolor_set (window, gui_color_weechat_get_pair (weechat_color), NULL);
 }
 
 /*
@@ -333,7 +345,7 @@ gui_window_set_color (WINDOW *window, int fg, int bg)
     gui_window_current_style_fg = fg;
     gui_window_current_style_bg = bg;
 
-    wattron (window, COLOR_PAIR(gui_color_get_pair (fg, bg)));
+    wcolor_set (window, gui_color_get_pair (fg, bg), NULL);
 }
 
 /*
@@ -408,7 +420,7 @@ gui_window_set_custom_color_fg (WINDOW *window, int fg)
         {
             if (!(fg & GUI_COLOR_EXTENDED_KEEPATTR_FLAG))
                 gui_window_remove_color_style (window, A_ALL_ATTR);
-            attributes = gui_color_get_extended_attrs (fg) |
+            attributes = gui_color_get_gui_attrs (fg) |
                 gui_weechat_colors[fg & GUI_COLOR_EXTENDED_MASK].attributes;
             gui_window_set_color_style (window, attributes);
             fg = gui_weechat_colors[fg & GUI_COLOR_EXTENDED_MASK].foreground;
@@ -493,7 +505,7 @@ gui_window_set_custom_color_fg_bg (WINDOW *window, int fg, int bg,
         {
             if (reset_attributes && !(fg & GUI_COLOR_EXTENDED_KEEPATTR_FLAG))
                 gui_window_remove_color_style (window, A_ALL_ATTR);
-            attributes = gui_color_get_extended_attrs (fg) |
+            attributes = gui_color_get_gui_attrs (fg) |
                 gui_weechat_colors[fg & GUI_COLOR_EXTENDED_MASK].attributes;
             gui_window_set_color_style (window, attributes);
             fg = gui_weechat_colors[fg & GUI_COLOR_EXTENDED_MASK].foreground;
@@ -532,7 +544,7 @@ gui_window_set_custom_color_pair (WINDOW *window, int pair)
     if ((pair >= 0) && (pair <= gui_color_num_pairs))
     {
         gui_window_remove_color_style (window, A_ALL_ATTR);
-        wattron (window, COLOR_PAIR(pair));
+        wcolor_set (window, pair, NULL);
     }
 }
 
@@ -792,7 +804,12 @@ gui_window_string_apply_color_fg_bg (unsigned char **string, WINDOW *window)
             ptr_string += 2;
         }
     }
-    if (ptr_string[0] == ',')
+    /*
+     * note: the comma is an old separator not used any more
+     * (since WeeChat 2.6), but we still use it here so in case of /upgrade
+     * this will not break colors in old messages
+     */
+    if ((ptr_string[0] == ',') || (ptr_string[0] == '~'))
     {
         ptr_string++;
         if (ptr_string[0] == GUI_COLOR_EXTENDED_CHAR)
@@ -1098,7 +1115,9 @@ gui_window_vline (WINDOW *window, int x, int y, int height, const char *string)
 void
 gui_window_draw_separators (struct t_gui_window *window)
 {
-    int separator_horizontal, separator_vertical, x, width;
+    int separator_horizontal, separator_vertical;
+    int horiz_overlap, x, width, height;
+    struct t_gui_window_tree *ptr_tree, *ptr_child;
 
     /* remove separators */
     if (GUI_WINDOW_OBJECTS(window)->win_separator_horiz)
@@ -1119,17 +1138,42 @@ gui_window_draw_separators (struct t_gui_window *window)
     separator_vertical = (CONFIG_BOOLEAN(config_look_window_separator_vertical)
                           && (window->win_x > gui_bar_root_get_size (NULL, GUI_BAR_POSITION_LEFT)));
 
+    /* check if horizontal separator must overlap in lower left corner */
+    horiz_overlap = 0;
+    ptr_child = window->ptr_tree;
+    ptr_tree = ptr_child->parent_node;
+    while (ptr_tree)
+    {
+        /* is right/top child */
+        if (ptr_tree->child2 == ptr_child)
+        {
+            /*
+             * horizontal overlap is needed when window is right in vertical
+             * split; it is not needed when window is top in horizontal split
+             */
+            horiz_overlap = !ptr_tree->split_horizontal;
+            break;
+        }
+
+        ptr_child = ptr_child->parent_node;
+        ptr_tree = ptr_tree->parent_node;
+    }
+
     /* create/draw horizontal separator */
     if (separator_horizontal)
     {
-        x = (separator_vertical) ? window->win_x - 1 : window->win_x;
-        width = (separator_vertical) ? window->win_width + 1 : window->win_width;
-        GUI_WINDOW_OBJECTS(window)->win_separator_horiz = newwin (1,
-                                                                  width,
-                                                                  window->win_y + window->win_height,
-                                                                  x);
-        gui_window_set_weechat_color (GUI_WINDOW_OBJECTS(window)->win_separator_horiz,
-                                      GUI_COLOR_SEPARATOR);
+        x = (separator_vertical && horiz_overlap) ?
+            window->win_x - 1 : window->win_x;
+        width = (separator_vertical && horiz_overlap) ?
+            window->win_width + 1 : window->win_width;
+        GUI_WINDOW_OBJECTS(window)->win_separator_horiz = newwin (
+            1,
+            width,
+            window->win_y + window->win_height,
+            x);
+        gui_window_set_weechat_color (
+            GUI_WINDOW_OBJECTS(window)->win_separator_horiz,
+            GUI_COLOR_SEPARATOR);
         gui_window_hline (GUI_WINDOW_OBJECTS(window)->win_separator_horiz,
                           0, 0, width,
                           CONFIG_STRING(config_look_separator_horizontal));
@@ -1139,14 +1183,18 @@ gui_window_draw_separators (struct t_gui_window *window)
     /* create/draw vertical separator */
     if (separator_vertical)
     {
-        GUI_WINDOW_OBJECTS(window)->win_separator_vertic = newwin (window->win_height,
-                                                                   1,
-                                                                   window->win_y,
-                                                                   window->win_x - 1);
-        gui_window_set_weechat_color (GUI_WINDOW_OBJECTS(window)->win_separator_vertic,
-                                      GUI_COLOR_SEPARATOR);
+        height = (separator_horizontal && !horiz_overlap) ?
+            window->win_height + 1 : window->win_height;
+        GUI_WINDOW_OBJECTS(window)->win_separator_vertic = newwin (
+            height,
+            1,
+            window->win_y,
+            window->win_x - 1);
+        gui_window_set_weechat_color (
+            GUI_WINDOW_OBJECTS(window)->win_separator_vertic,
+            GUI_COLOR_SEPARATOR);
         gui_window_vline (GUI_WINDOW_OBJECTS(window)->win_separator_vertic,
-                          0, 0, window->win_height,
+                          0, 0, height,
                           CONFIG_STRING(config_look_separator_vertical));
         wnoutrefresh (GUI_WINDOW_OBJECTS(window)->win_separator_vertic);
     }
@@ -1800,6 +1848,9 @@ gui_window_split_horizontal (struct t_gui_window *window, int percentage)
             gui_window_ask_refresh (1);
 
             gui_window_switch (new_window);
+
+            /* create & draw separators */
+            gui_window_draw_separators (gui_current_window);
         }
     }
 
@@ -1964,40 +2015,39 @@ gui_window_merge (struct t_gui_window *window)
         return 0;
 
     parent = window->ptr_tree->parent_node;
-    if (parent)
+    if (!parent)
+        return 0;
+
+    sister = (parent->child1->window == window) ?
+        parent->child2 : parent->child1;
+    if (!(sister->window))
+        return 0;
+
+    if (window->win_y == sister->window->win_y)
     {
-        sister = (parent->child1->window == window) ?
-            parent->child2 : parent->child1;
-
-        if (!(sister->window))
-            return 0;
-
-        if (window->win_y == sister->window->win_y)
-        {
-            /* horizontal merge */
-            separator = (CONFIG_BOOLEAN(config_look_window_separator_horizontal)) ? 1 : 0;
-            window->win_width += sister->window->win_width + separator;
-            window->win_width_pct += sister->window->win_width_pct;
-        }
-        else
-        {
-            /* vertical merge */
-            separator = (CONFIG_BOOLEAN(config_look_window_separator_vertical)) ? 1 : 0;
-            window->win_height += sister->window->win_height + separator;
-            window->win_height_pct += sister->window->win_height_pct;
-        }
-        if (sister->window->win_x < window->win_x)
-            window->win_x = sister->window->win_x;
-        if (sister->window->win_y < window->win_y)
-            window->win_y = sister->window->win_y;
-
-        gui_window_free (sister->window);
-        gui_window_tree_node_to_leaf (parent, window);
-
-        gui_window_switch_to_buffer (window, window->buffer, 1);
-        return 1;
+        /* horizontal merge */
+        separator = (CONFIG_BOOLEAN(config_look_window_separator_horizontal)) ? 1 : 0;
+        window->win_width += sister->window->win_width + separator;
+        window->win_width_pct += sister->window->win_width_pct;
     }
-    return 0;
+    else
+    {
+        /* vertical merge */
+        separator = (CONFIG_BOOLEAN(config_look_window_separator_vertical)) ? 1 : 0;
+        window->win_height += sister->window->win_height + separator;
+        window->win_height_pct += sister->window->win_height_pct;
+    }
+    if (sister->window->win_x < window->win_x)
+        window->win_x = sister->window->win_x;
+    if (sister->window->win_y < window->win_y)
+        window->win_y = sister->window->win_y;
+
+    gui_window_free (sister->window);
+    gui_window_tree_node_to_leaf (parent, window);
+
+    gui_window_switch_to_buffer (window, window->buffer, 1);
+
+    return 1;
 }
 
 /*
@@ -2042,6 +2092,34 @@ gui_window_merge_all (struct t_gui_window *window)
     }
 }
 
+/*
+ * Closes a window.
+ *
+ * Returns:
+ *   1: OK
+ *   0: error
+ */
+
+int
+gui_window_close (struct t_gui_window *window)
+{
+    struct t_gui_window_tree *parent, *sister;
+
+    if (!gui_init_ok)
+        return 0;
+
+    parent = window->ptr_tree->parent_node;
+    if (!parent)
+        return 0;
+
+    sister = (parent->child1->window == window) ?
+        parent->child2 : parent->child1;
+    if (!(sister->window))
+        return 0;
+
+    return gui_window_merge (sister->window);
+}
+
 /*
  * Returns a code about position of 2 windows:
  *   0 = they're not side by side
