@@ -166,6 +166,30 @@ gui_chat_char_size_screen (const char *utf_char)
     return utf8_char_size_screen (utf_char);
 }
 
+/*
+ * Returns number of char in a string (special chars like colors/attributes are
+ * ignored).
+ */
+
+int
+gui_chat_strlen (const char *string)
+{
+    int length;
+
+    length = 0;
+    while (string && string[0])
+    {
+        string = gui_chat_string_next_char (NULL, NULL,
+                                            (unsigned char *)string, 0, 0, 0);
+        if (string)
+        {
+            length++;
+            string = utf8_next_char (string);
+        }
+    }
+    return length;
+}
+
 /*
  * Returns number of char needed on screen to display a word (special chars like
  * colors/attributes are ignored).
@@ -910,7 +934,7 @@ gui_chat_print_lines_waiting_buffer (FILE *f)
 
     if (gui_chat_lines_waiting_buffer)
     {
-        lines = string_split (*gui_chat_lines_waiting_buffer, "\n",
+        lines = string_split (*gui_chat_lines_waiting_buffer, "\n", NULL,
                               WEECHAT_STRING_SPLIT_STRIP_LEFT
                               | WEECHAT_STRING_SPLIT_STRIP_RIGHT
                               | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
