@@ -914,9 +914,24 @@ weechat_guile_command_cb (const void *pointer, void *data,
                 else
                     break;
             }
+            /*
+             * FIXME: this does not yet work with Guile >= 2.2, so the eval
+             * feature is temporarily disabled, waiting for a fix
+             */
+            /*
             if (!weechat_guile_eval (buffer, send_to_buffer_as_input,
                                      exec_commands, ptr_code))
                 WEECHAT_COMMAND_ERROR;
+            */
+            /* TODO: fix /guile eval */
+            (void) buffer;
+            (void) ptr_code;
+            (void) send_to_buffer_as_input;
+            (void) exec_commands;
+            weechat_printf (NULL,
+                            _("%sCommand \"/%s eval\" is not yet implemented"),
+                            weechat_prefix ("error"),
+                            weechat_guile_plugin->name);
         }
         else
             WEECHAT_COMMAND_ERROR;
@@ -1127,6 +1142,21 @@ weechat_guile_signal_script_action_cb (const void *pointer, void *data,
  * Fills input.
  */
 
+#if SCM_MAJOR_VERSION >= 3 || (SCM_MAJOR_VERSION == 2 && SCM_MINOR_VERSION >= 2)
+/* Guile >= 2.2 */
+size_t
+weechat_guile_port_fill_input (SCM port, SCM dst, size_t start, size_t count)
+{
+    /* make C compiler happy */
+    (void) port;
+    (void) dst;
+    (void) start;
+    (void) count;
+
+    return ' ';
+}
+#else
+/* Guile < 2.2 */
 int
 weechat_guile_port_fill_input (SCM port)
 {
@@ -1135,11 +1165,47 @@ weechat_guile_port_fill_input (SCM port)
 
     return ' ';
 }
+#endif
 
 /*
  * Write.
  */
 
+#if SCM_MAJOR_VERSION >= 3 || (SCM_MAJOR_VERSION == 2 && SCM_MINOR_VERSION >= 2)
+/* Guile >= 2.2 */
+size_t
+weechat_guile_port_write (SCM port, SCM src, size_t start, size_t count)
+{
+    char *data2, *ptr_data, *ptr_newline;
+    const char *data;
+
+    /* make C compiler happy */
+    (void) port;
+
+    data = scm_to_locale_string (src);
+
+    data2 = malloc (count + 1);
+    if (!data2)
+        return 0;
+
+    memcpy (data2, data + start, count);
+    data2[count] = '\0';
+
+    ptr_data = data2;
+    while ((ptr_newline = strchr (ptr_data, '\n')) != NULL)
+    {
+        ptr_newline[0] = '\0';
+        weechat_string_dyn_concat (guile_buffer_output, ptr_data);
+        weechat_guile_output_flush ();
+        ptr_newline[0] = '\n';
+        ptr_data = ++ptr_newline;
+    }
+    weechat_string_dyn_concat (guile_buffer_output, ptr_data);
+
+    return count;
+}
+#else
+/* Guile < 2.2 */
 void
 weechat_guile_port_write (SCM port, const void *data, size_t size)
 {
@@ -1166,6 +1232,7 @@ weechat_guile_port_write (SCM port, const void *data, size_t size)
     }
     weechat_string_dyn_concat (guile_buffer_output, ptr_data);
 }
+#endif
 
 /*
  * Initializes guile plugin.
