@@ -103,6 +103,10 @@ extern void irc_channel_add_nicklist_groups (struct t_irc_server *server,
 extern void irc_channel_set_buffer_title (struct t_irc_channel *channel);
 extern void irc_channel_set_topic (struct t_irc_channel *channel,
                                    const char *topic);
+extern void irc_channel_set_topic_private_buffers (struct t_irc_server *server,
+                                                   struct t_irc_nick *nick,
+                                                   const char *nickname,
+                                                   const char *topic);
 extern void irc_channel_set_modes (struct t_irc_channel *channel,
                                    const char *modes);
 extern void irc_channel_free (struct t_irc_server *server,
