@@ -110,6 +110,7 @@ extern struct t_config_option *irc_config_look_display_join_message;
 extern struct t_config_option *irc_config_look_display_old_topic;
 extern struct t_config_option *irc_config_look_display_pv_away_once;
 extern struct t_config_option *irc_config_look_display_pv_back;
+extern struct t_config_option *irc_config_look_display_pv_warning_address;
 extern struct t_config_option *irc_config_look_highlight_channel;
 extern struct t_config_option *irc_config_look_highlight_pv;
 extern struct t_config_option *irc_config_look_highlight_server;
@@ -152,12 +153,14 @@ extern struct t_config_option *irc_config_color_item_channel_modes;
 extern struct t_config_option *irc_config_color_item_lag_counting;
 extern struct t_config_option *irc_config_color_item_lag_finished;
 extern struct t_config_option *irc_config_color_item_nick_modes;
-extern struct t_config_option *irc_config_color_message_join;
 extern struct t_config_option *irc_config_color_message_chghost;
+extern struct t_config_option *irc_config_color_message_join;
+extern struct t_config_option *irc_config_color_message_kick;
 extern struct t_config_option *irc_config_color_message_quit;
 extern struct t_config_option *irc_config_color_mirc_remap;
 extern struct t_config_option *irc_config_color_nick_prefixes;
 extern struct t_config_option *irc_config_color_notice;
+extern struct t_config_option *irc_config_color_reason_kick;
 extern struct t_config_option *irc_config_color_reason_quit;
 extern struct t_config_option *irc_config_color_topic_current;
 extern struct t_config_option *irc_config_color_topic_new;
@@ -166,7 +169,6 @@ extern struct t_config_option *irc_config_color_topic_old;
 extern struct t_config_option *irc_config_network_autoreconnect_delay_growing;
 extern struct t_config_option *irc_config_network_autoreconnect_delay_max;
 extern struct t_config_option *irc_config_network_ban_mask_default;
-extern struct t_config_option *irc_config_network_channel_encode;
 extern struct t_config_option *irc_config_network_colors_receive;
 extern struct t_config_option *irc_config_network_colors_send;
 extern struct t_config_option *irc_config_network_lag_check;
