@@ -25,8 +25,9 @@ struct t_irc_channel;
 
 extern void irc_message_parse (struct t_irc_server *server, const char *message,
                                char **tags, char **message_without_tags,
-                               char **nick, char **host, char **command,
-                               char **channel, char **arguments, char **text,
+                               char **nick, char **user, char **host,
+                               char **command, char **channel,
+                               char **arguments, char **text,
                                int *pos_command, int *pos_arguments,
                                int *pos_channel, int *pos_text);
 extern struct t_hashtable *irc_message_parse_to_hashtable (struct t_irc_server *server,
