@@ -48,8 +48,9 @@ struct t_irc_nick
 extern int irc_nick_valid (struct t_irc_channel *channel,
                            struct t_irc_nick *nick);
 extern int irc_nick_is_nick (const char *string);
-extern const char *irc_nick_find_color (const char *nickname);
-extern const char *irc_nick_find_color_name (const char *nickname);
+extern char *irc_nick_find_color (const char *nickname);
+extern char *irc_nick_find_color_name (const char *nickname);
+extern void irc_nick_set_host (struct t_irc_nick *nick, const char *host);
 extern int irc_nick_is_op (struct t_irc_server *server,
                            struct t_irc_nick *nick);
 extern int irc_nick_has_prefix_mode (struct t_irc_server *server,
@@ -73,6 +74,8 @@ extern void irc_nick_change (struct t_irc_server *server,
 extern void irc_nick_set_mode (struct t_irc_server *server,
                                struct t_irc_channel *channel,
                                struct t_irc_nick *nick, int set, char mode);
+extern void irc_nick_realloc_prefixes (struct t_irc_server *server,
+                                       int old_length, int new_length);
 extern void irc_nick_free (struct t_irc_server *server,
                            struct t_irc_channel *channel,
                            struct t_irc_nick *nick);
