@@ -1,7 +1,7 @@
 /*
  * irc-notify.c - notify lists for IRC plugin
  *
- * Copyright (C) 2010-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2010-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <stdlib.h>
@@ -373,7 +373,11 @@ irc_notify_new_for_server (struct t_irc_server *server)
     if (!notify || !notify[0])
         return;
 
-    items = weechat_string_split (notify, ",", 0, 0, &num_items);
+    items = weechat_string_split (notify, ",", NULL,
+                                  WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                  | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                  | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                  0, &num_items);
     if (items)
     {
         for (i = 0; i < num_items; i++)
@@ -388,8 +392,15 @@ irc_notify_new_for_server (struct t_irc_server *server)
                 {
                     pos_params++;
                 }
-                params = weechat_string_split (pos_params, "/", 0, 0,
-                                               &num_params);
+                params = weechat_string_split (
+                    pos_params,
+                    "/",
+                    NULL,
+                    WEECHAT_STRING_SPLIT_STRIP_LEFT
+                    | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                    | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                    0,
+                    &num_params);
                 if (params)
                 {
                     for (j = 0; j < num_params; j++)
@@ -827,11 +838,26 @@ irc_notify_hsignal_cb (const void *pointer, void *data, const char *signal,
     if (strcmp (pattern, "ison") == 0)
     {
         /* redirection of command "ison" */
-        messages = weechat_string_split (output, "\n", 0, 0, &num_messages);
+        messages = weechat_string_split (
+            output,
+            "\n",
+            NULL,
+            WEECHAT_STRING_SPLIT_STRIP_LEFT
+            | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+            | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+            0,
+            &num_messages);
         if (messages)
         {
-            nicks_sent = weechat_string_split (ptr_args, " ", 0, 0,
-                                               &num_nicks_sent);
+            nicks_sent = weechat_string_split (
+                ptr_args,
+                " ",
+                NULL,
+                WEECHAT_STRING_SPLIT_STRIP_LEFT
+                | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                0,
+                &num_nicks_sent);
             if (!nicks_sent)
                 return WEECHAT_RC_OK;
             for (ptr_notify = ptr_server->notify_list;
@@ -843,8 +869,8 @@ irc_notify_hsignal_cb (const void *pointer, void *data, const char *signal,
             for (i = 0; i < num_messages; i++)
             {
                 irc_message_parse (ptr_server, messages[i], NULL, NULL, NULL,
-                                   NULL, NULL, NULL, &arguments, NULL, NULL,
-                                   NULL, NULL, NULL);
+                                   NULL, NULL, NULL, NULL, &arguments, NULL,
+                                   NULL, NULL, NULL, NULL);
                 if (arguments)
                 {
                     pos = strchr (arguments, ' ');
@@ -857,8 +883,15 @@ irc_notify_hsignal_cb (const void *pointer, void *data, const char *signal,
                         }
                         if (pos[0])
                         {
-                            nicks_recv = weechat_string_split (pos, " ", 0, 0,
-                                                               &num_nicks_recv);
+                            nicks_recv = weechat_string_split (
+                                pos,
+                                " ",
+                                NULL,
+                                WEECHAT_STRING_SPLIT_STRIP_LEFT
+                                | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                                | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                                0,
+                                &num_nicks_recv);
                             if (nicks_recv)
                             {
                                 for (j = 0; j < num_nicks_recv; j++)
@@ -920,14 +953,23 @@ irc_notify_hsignal_cb (const void *pointer, void *data, const char *signal,
         {
             away_message_updated = 0;
             no_such_nick = 0;
-            messages = weechat_string_split (output, "\n", 0, 0, &num_messages);
+            messages = weechat_string_split (
+                output,
+                "\n",
+                NULL,
+                WEECHAT_STRING_SPLIT_STRIP_LEFT
+                | WEECHAT_STRING_SPLIT_STRIP_RIGHT
+                | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
+                0,
+                &num_messages);
             if (messages)
             {
                 for (i = 0; i < num_messages; i++)
                 {
-                    irc_message_parse (ptr_server, messages[0], NULL, NULL,
-                                       NULL, NULL, &irc_cmd, NULL, &arguments,
-                                       NULL, NULL, NULL, NULL, NULL);
+                    irc_message_parse (ptr_server, messages[i], NULL, NULL,
+                                       NULL, NULL, NULL, &irc_cmd, NULL,
+                                       &arguments, NULL, NULL, NULL, NULL,
+                                       NULL);
                     if (irc_cmd && arguments)
                     {
                         if (strcmp (irc_cmd, "401") == 0)
