@@ -42,6 +42,13 @@ enum t_irc_server_sasl_fail
     IRC_SERVER_NUM_SASL_FAIL,
 };
 
+enum t_irc_server_charset_message
+{
+    IRC_SERVER_CHARSET_MESSAGE_MESSAGE = 0,
+    IRC_SERVER_CHARSET_MESSAGE_CHANNEL,
+    IRC_SERVER_CHARSET_MESSAGE_TEXT,
+};
+
 enum t_irc_server_option
 {
     IRC_SERVER_OPTION_ADDRESSES = 0, /* server addresses (IP/name with port) */
@@ -49,6 +56,7 @@ enum t_irc_server_option
     IRC_SERVER_OPTION_IPV6,          /* use IPv6 protocol                    */
     IRC_SERVER_OPTION_SSL,           /* SSL protocol                         */
     IRC_SERVER_OPTION_SSL_CERT,      /* client ssl certificate file          */
+    IRC_SERVER_OPTION_SSL_PASSWORD,   /* client ssl certificate key password */
     IRC_SERVER_OPTION_SSL_PRIORITIES, /* gnutls priorities                   */
     IRC_SERVER_OPTION_SSL_DHKEY_SIZE, /* Diffie Hellman key size             */
     IRC_SERVER_OPTION_SSL_FINGERPRINT, /* SHA1 fingerprint of certificate    */
@@ -85,6 +93,7 @@ enum t_irc_server_option
     IRC_SERVER_OPTION_MSG_QUIT,             /* default quit message          */
     IRC_SERVER_OPTION_NOTIFY,               /* notify list                   */
     IRC_SERVER_OPTION_SPLIT_MSG_MAX_LENGTH, /* max length of messages        */
+    IRC_SERVER_OPTION_CHARSET_MESSAGE,      /* what to decode/encode in msg  */
     /* number of server options */
     IRC_SERVER_NUM_OPTIONS,
 };
@@ -201,6 +210,8 @@ struct t_irc_server
     char *prefix_modes;             /* prefix modes from msg 005 (eg "ohv")  */
     char *prefix_chars;             /* prefix chars from msg 005 (eg "@%+")  */
     int nick_max_length;            /* max length of nick (from msg 005)     */
+    int user_max_length;            /* max length of user (from msg 005)     */
+    int host_max_length;            /* max length of host (from msg 005)     */
     int casemapping;                /* casemapping from msg 005              */
     char *chantypes;                /* chantypes from msg 005 (eg "&#")      */
     char *chanmodes;                /* chanmodes from msg 005                */
