@@ -1,7 +1,7 @@
 /*
  * logger-buffer.c - logger buffer list management
  *
- * Copyright (C) 2003-2018 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2019 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with WeeChat.  If not, see <http://www.gnu.org/licenses/>.
+ * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -91,6 +91,7 @@ logger_buffer_add (struct t_gui_buffer *buffer, int log_level)
         new_logger_buffer->buffer = buffer;
         new_logger_buffer->log_filename = NULL;
         new_logger_buffer->log_file = NULL;
+        new_logger_buffer->log_file_inode = 0;
         new_logger_buffer->log_enabled = 1;
         new_logger_buffer->log_level = log_level;
         new_logger_buffer->write_start_info_line = 1;
@@ -234,6 +235,8 @@ logger_buffer_add_to_infolist (struct t_infolist *infolist,
         return 0;
     if (!weechat_infolist_new_var_pointer (ptr_item, "log_file", logger_buffer->log_file))
         return 0;
+    if (!weechat_infolist_new_var_buffer (ptr_item, "log_file_inode", &(logger_buffer->log_file_inode), sizeof(logger_buffer->log_file_inode)))
+        return 0;
     if (!weechat_infolist_new_var_integer (ptr_item, "log_enabled", logger_buffer->log_enabled))
         return 0;
     if (!weechat_infolist_new_var_integer (ptr_item, "log_level", logger_buffer->log_level))
