@@ -19,11 +19,6 @@
  * along with WeeChat.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-/* this define is needed for strptime() (not on OpenBSD/Sun) */
-#if !defined(__OpenBSD__) && !defined(__sun)
-#define _XOPEN_SOURCE 700
-#endif
-
 #include <stdlib.h>
 #include <unistd.h>
 #include <errno.h>
@@ -39,6 +34,7 @@
 
 #include "../weechat-plugin.h"
 #include "logger.h"
+#include "logger-backlog.h"
 #include "logger-buffer.h"
 #include "logger-command.h"
 #include "logger-config.h"
@@ -55,7 +51,8 @@ WEECHAT_PLUGIN_PRIORITY(14000);
 
 struct t_weechat_plugin *weechat_logger_plugin = NULL;
 
-struct t_hook *logger_timer = NULL;    /* timer to flush log files          */
+struct t_hook *logger_hook_timer = NULL;    /* timer to flush log files     */
+struct t_hook *logger_hook_print = NULL;
 
 
 /*
@@ -518,6 +515,132 @@ logger_set_log_filename (struct t_logger_buffer *logger_buffer)
     logger_buffer->log_filename = log_filename;
 }
 
+/*
+ * Creates a log file.
+ *
+ * Returns:
+ *   1: OK
+ *   0: error
+ */
+
+int
+logger_create_log_file (struct t_logger_buffer *logger_buffer)
+{
+    char *charset, *message, buf_time[256], buf_beginning[1024];
+    int log_level, rc;
+    time_t seconds;
+    struct tm *date_tmp;
+    struct stat statbuf;
+
+    if (logger_buffer->log_file)
+    {
+        /*
+         * check that the inode has not changed, otherwise that means the file
+         * was deleted, and we must reopen it
+         */
+        rc = stat (logger_buffer->log_filename, &statbuf);
+        if ((rc == 0) && (statbuf.st_ino == logger_buffer->log_file_inode))
+        {
+            /* inode has not changed, we can write in this file */
+            return 1;
+        }
+        fclose (logger_buffer->log_file);
+        logger_buffer->log_file = NULL;
+        logger_buffer->log_file_inode = 0;
+    }
+
+    /* get log level */
+    log_level = logger_get_level_for_buffer (logger_buffer->buffer);
+    if (log_level == 0)
+    {
+        logger_buffer_free (logger_buffer);
+        return 0;
+    }
+
+    /* create directory */
+    if (!logger_create_directory ())
+    {
+        weechat_printf_date_tags (
+            NULL, 0, "no_log",
+            _("%s%s: unable to create directory for logs "
+              "(\"%s\")"),
+            weechat_prefix ("error"), LOGGER_PLUGIN_NAME,
+            weechat_config_string (logger_config_file_path));
+        logger_buffer_free (logger_buffer);
+        return 0;
+    }
+    if (!logger_buffer->log_filename)
+        logger_set_log_filename (logger_buffer);
+    if (!logger_buffer->log_filename)
+    {
+        logger_buffer_free (logger_buffer);
+        return 0;
+    }
+
+    /* create or append to log file */
+    logger_buffer->log_file =
+        fopen (logger_buffer->log_filename, "a");
+    if (!logger_buffer->log_file)
+    {
+        weechat_printf_date_tags (
+            NULL, 0, "no_log",
+            _("%s%s: unable to write log file \"%s\": %s"),
+            weechat_prefix ("error"), LOGGER_PLUGIN_NAME,
+            logger_buffer->log_filename, strerror (errno));
+        logger_buffer_free (logger_buffer);
+        return 0;
+    }
+
+    /* get file inode */
+    rc = stat (logger_buffer->log_filename, &statbuf);
+    if (rc != 0)
+    {
+        weechat_printf_date_tags (
+            NULL, 0, "no_log",
+            _("%s%s: unable to get file status of log file \"%s\": %s"),
+            weechat_prefix ("error"), LOGGER_PLUGIN_NAME,
+            logger_buffer->log_filename, strerror (errno));
+        fclose (logger_buffer->log_file);
+        logger_buffer->log_file = NULL;
+        logger_buffer->log_file_inode = 0;
+        logger_buffer_free (logger_buffer);
+        return 0;
+    }
+    logger_buffer->log_file_inode = statbuf.st_ino;
+
+    /* write info line */
+    if (weechat_config_boolean (logger_config_file_info_lines)
+        && logger_buffer->write_start_info_line)
+    {
+        buf_time[0] = '\0';
+        seconds = time (NULL);
+        date_tmp = localtime (&seconds);
+        if (date_tmp)
+        {
+            if (strftime (buf_time, sizeof (buf_time) - 1,
+                          weechat_config_string (logger_config_file_time_format),
+                          date_tmp) == 0)
+                buf_time[0] = '\0';
+        }
+        snprintf (buf_beginning, sizeof (buf_beginning),
+                  _("%s\t****  Beginning of log  ****"),
+                  buf_time);
+        charset = weechat_info_get ("charset_terminal", "");
+        message = (charset) ?
+            weechat_iconv_from_internal (charset, buf_beginning) : NULL;
+        fprintf (logger_buffer->log_file,
+                 "%s\n", (message) ? message : buf_beginning);
+        if (charset)
+            free (charset);
+        if (message)
+            free (message);
+        logger_buffer->flush_needed = 1;
+    }
+    logger_buffer->write_start_info_line = 0;
+
+    return 1;
+}
+
 /*
  * Writes a line to log file.
  */
@@ -526,80 +649,10 @@ void
 logger_write_line (struct t_logger_buffer *logger_buffer,
                    const char *format, ...)
 {
-    char *message, buf_time[256], buf_beginning[1024], *charset;
-    time_t seconds;
-    struct tm *date_tmp;
-    int log_level;
+    char *charset, *message;
 
-    if (!logger_buffer->log_file)
-    {
-        log_level = logger_get_level_for_buffer (logger_buffer->buffer);
-        if (log_level == 0)
-        {
-            logger_buffer_free (logger_buffer);
-            return;
-        }
-        if (!logger_create_directory ())
-        {
-            weechat_printf_date_tags (
-                NULL, 0, "no_log",
-                _("%s%s: unable to create directory for logs "
-                  "(\"%s\")"),
-                weechat_prefix ("error"), LOGGER_PLUGIN_NAME,
-                weechat_config_string (logger_config_file_path));
-            logger_buffer_free (logger_buffer);
-            return;
-        }
-        if (!logger_buffer->log_filename)
-            logger_set_log_filename (logger_buffer);
-        if (!logger_buffer->log_filename)
-        {
-            logger_buffer_free (logger_buffer);
-            return;
-        }
-
-        logger_buffer->log_file =
-            fopen (logger_buffer->log_filename, "a");
-        if (!logger_buffer->log_file)
-        {
-            weechat_printf_date_tags (
-                NULL, 0, "no_log",
-                _("%s%s: unable to write log file \"%s\": %s"),
-                weechat_prefix ("error"), LOGGER_PLUGIN_NAME,
-                logger_buffer->log_filename, strerror (errno));
-            logger_buffer_free (logger_buffer);
-            return;
-        }
-
-        if (weechat_config_boolean (logger_config_file_info_lines)
-            && logger_buffer->write_start_info_line)
-        {
-            buf_time[0] = '\0';
-            seconds = time (NULL);
-            date_tmp = localtime (&seconds);
-            if (date_tmp)
-            {
-                if (strftime (buf_time, sizeof (buf_time) - 1,
-                              weechat_config_string (logger_config_file_time_format),
-                              date_tmp) == 0)
-                    buf_time[0] = '\0';
-            }
-            snprintf (buf_beginning, sizeof (buf_beginning),
-                      _("%s\t****  Beginning of log  ****"),
-                      buf_time);
-            charset = weechat_info_get ("charset_terminal", "");
-            message = (charset) ?
-                weechat_iconv_from_internal (charset, buf_beginning) : NULL;
-            fprintf (logger_buffer->log_file,
-                     "%s\n", (message) ? message : buf_beginning);
-            if (charset)
-                free (charset);
-            if (message)
-                free (message);
-            logger_buffer->flush_needed = 1;
-        }
-        logger_buffer->write_start_info_line = 0;
-    }
+    if (!logger_create_log_file (logger_buffer))
+        return;
 
     weechat_va_format (format);
     if (vbuffer)
@@ -614,7 +667,7 @@ logger_write_line (struct t_logger_buffer *logger_buffer,
         if (message)
             free (message);
         logger_buffer->flush_needed = 1;
-        if (!logger_timer)
+        if (!logger_hook_timer)
         {
             fflush (logger_buffer->log_file);
             if (weechat_config_boolean (logger_config_file_fsync))
@@ -659,6 +712,7 @@ logger_stop (struct t_logger_buffer *logger_buffer, int write_info_line)
         }
         fclose (logger_buffer->log_file);
         logger_buffer->log_file = NULL;
+        logger_buffer->log_file_inode = 0;
     }
     logger_buffer_free (logger_buffer);
 }
@@ -719,6 +773,7 @@ logger_start_buffer (struct t_gui_buffer *buffer, int write_info_line)
                     {
                         fclose (ptr_logger_buffer->log_file);
                         ptr_logger_buffer->log_file = NULL;
+                        ptr_logger_buffer->log_file_inode = 0;
                     }
                 }
             }
@@ -840,186 +895,6 @@ logger_buffer_renamed_signal_cb (const void *pointer, void *data,
     return WEECHAT_RC_OK;
 }
 
-/*
- * Checks conditions to display the backlog.
- *
- * Returns:
- *   1: conditions OK (backlog is displayed)
- *   0: conditions not OK (backlog is NOT displayed)
- */
-
-int
-logger_backlog_check_conditions (struct t_gui_buffer *buffer)
-{
-    struct t_hashtable *pointers, *options;
-    const char *ptr_condition;
-    char *result;
-    int condition_ok;
-
-    ptr_condition = weechat_config_string (logger_config_look_backlog_conditions);
-
-    /* empty condition displays the backlog everywhere */
-    if (!ptr_condition || !ptr_condition[0])
-        return 1;
-
-    pointers = weechat_hashtable_new (32,
-                                      WEECHAT_HASHTABLE_STRING,
-                                      WEECHAT_HASHTABLE_POINTER,
-                                      NULL,
-                                      NULL);
-    if (pointers)
-    {
-        weechat_hashtable_set (pointers, "window",
-                               weechat_window_search_with_buffer (buffer));
-        weechat_hashtable_set (pointers, "buffer", buffer);
-    }
-
-    options = weechat_hashtable_new (32,
-                                     WEECHAT_HASHTABLE_STRING,
-                                     WEECHAT_HASHTABLE_STRING,
-                                     NULL,
-                                     NULL);
-    if (options)
-        weechat_hashtable_set (options, "type", "condition");
-
-    result = weechat_string_eval_expression (ptr_condition,
-                                             pointers, NULL, options);
-    condition_ok = (result && (strcmp (result, "1") == 0));
-    if (result)
-        free (result);
-
-    if (pointers)
-        weechat_hashtable_free (pointers);
-    if (options)
-        weechat_hashtable_free (options);
-
-    return condition_ok;
-}
-
-/*
- * Displays backlog for a buffer (by reading end of log file).
- */
-
-void
-logger_backlog (struct t_gui_buffer *buffer, const char *filename, int lines)
-{
-    struct t_logger_line *last_lines, *ptr_lines;
-    char *charset, *pos_message, *pos_tab, *error, *message;
-    time_t datetime, time_now;
-    struct tm tm_line;
-    int num_lines;
-
-    weechat_buffer_set (buffer, "print_hooks_enabled", "0");
-
-    num_lines = 0;
-    last_lines = logger_tail_file (filename, lines);
-    ptr_lines = last_lines;
-    while (ptr_lines)
-    {
-        datetime = 0;
-        pos_message = strchr (ptr_lines->data, '\t');
-        if (pos_message)
-        {
-            /* initialize structure, because strptime does not do it */
-            memset (&tm_line, 0, sizeof (struct tm));
-            /*
-             * we get current time to initialize daylight saving time in
-             * structure tm_line, otherwise printed time will be shifted
-             * and will not use DST used on machine
-             */
-            time_now = time (NULL);
-            localtime_r (&time_now, &tm_line);
-            pos_message[0] = '\0';
-            error = strptime (ptr_lines->data,
-                              weechat_config_string (logger_config_file_time_format),
-                              &tm_line);
-            if (error && !error[0] && (tm_line.tm_year > 0))
-                datetime = mktime (&tm_line);
-            pos_message[0] = '\t';
-        }
-        pos_message = (pos_message && (datetime != 0)) ?
-            pos_message + 1 : ptr_lines->data;
-        charset = weechat_info_get ("charset_terminal", "");
-        message = (charset) ?
-            weechat_iconv_to_internal (charset, pos_message) : strdup (pos_message);
-        if (charset)
-            free (charset);
-        if (message)
-        {
-            pos_tab = strchr (message, '\t');
-            if (pos_tab)
-                pos_tab[0] = '\0';
-            weechat_printf_date_tags (buffer, datetime,
-                                      "no_highlight,notify_none,logger_backlog",
-                                      "%s%s%s%s%s",
-                                      weechat_color (weechat_config_string (logger_config_color_backlog_line)),
-                                      message,
-                                      (pos_tab) ? "\t" : "",
-                                      (pos_tab) ? weechat_color (weechat_config_string (logger_config_color_backlog_line)) : "",
-                                      (pos_tab) ? pos_tab + 1 : "");
-            if (pos_tab)
-                pos_tab[0] = '\t';
-            free (message);
-        }
-        num_lines++;
-        ptr_lines = ptr_lines->next_line;
-    }
-    if (last_lines)
-        logger_tail_free (last_lines);
-    if (num_lines > 0)
-    {
-        weechat_printf_date_tags (buffer, datetime,
-                                  "no_highlight,notify_none,logger_backlog_end",
-                                  _("%s===\t%s========== End of backlog (%d lines) =========="),
-                                  weechat_color (weechat_config_string (logger_config_color_backlog_end)),
-                                  weechat_color (weechat_config_string (logger_config_color_backlog_end)),
-                                  num_lines);
-        weechat_buffer_set (buffer, "unread", "");
-    }
-    weechat_buffer_set (buffer, "print_hooks_enabled", "1");
-}
-
-/*
- * Callback for signal "logger_backlog".
- */
-
-int
-logger_backlog_signal_cb (const void *pointer, void *data,
-                          const char *signal,
-                          const char *type_data, void *signal_data)
-{
-    struct t_logger_buffer *ptr_logger_buffer;
-
-    /* make C compiler happy */
-    (void) pointer;
-    (void) data;
-    (void) signal;
-    (void) type_data;
-
-    if (weechat_config_integer (logger_config_look_backlog) == 0)
-        return WEECHAT_RC_OK;
-
-    if (!logger_backlog_check_conditions (signal_data))
-        return WEECHAT_RC_OK;
-
-    ptr_logger_buffer = logger_buffer_search_buffer (signal_data);
-    if (ptr_logger_buffer && ptr_logger_buffer->log_enabled)
-    {
-        if (!ptr_logger_buffer->log_filename)
-            logger_set_log_filename (ptr_logger_buffer);
-        if (ptr_logger_buffer->log_filename)
-        {
-            ptr_logger_buffer->log_enabled = 0;
-            logger_backlog (signal_data,
-                            ptr_logger_buffer->log_filename,
-                            weechat_config_integer (logger_config_look_backlog));
-            ptr_logger_buffer->log_enabled = 1;
-        }
-    }
-
-    return WEECHAT_RC_OK;
-}
-
 /*
  * Callback for signal "logger_start".
  */
@@ -1191,8 +1066,9 @@ logger_print_cb (const void *pointer, void *data,
 {
     struct t_logger_buffer *ptr_logger_buffer;
     struct tm *date_tmp;
-    char buf_time[256];
-    int line_log_level, prefix_is_nick;
+    char buf_time[256], *prefix_ansi, *message_ansi;
+    const char *ptr_prefix, *ptr_message;
+    int line_log_level, prefix_is_nick, color_lines;
 
     /* make C compiler happy */
     (void) pointer;
@@ -1202,32 +1078,56 @@ logger_print_cb (const void *pointer, void *data,
 
     logger_get_line_tag_info (tags_count, tags, &line_log_level,
                               &prefix_is_nick);
-    if (line_log_level >= 0)
-    {
-        ptr_logger_buffer = logger_buffer_search_buffer (buffer);
-        if (ptr_logger_buffer
-            && ptr_logger_buffer->log_enabled
-            && (date > 0)
-            && (line_log_level <= ptr_logger_buffer->log_level))
-        {
-            buf_time[0] = '\0';
-            date_tmp = localtime (&date);
-            if (date_tmp)
-            {
-                if (strftime (buf_time, sizeof (buf_time) - 1,
-                              weechat_config_string (logger_config_file_time_format),
-                              date_tmp) == 0)
-                    buf_time[0] = '\0';
-            }
+    if (line_log_level < 0)
+        return WEECHAT_RC_OK;
 
-            logger_write_line (ptr_logger_buffer,
-                               "%s\t%s%s%s\t%s",
-                               buf_time,
-                               (prefix && prefix_is_nick) ? weechat_config_string (logger_config_file_nick_prefix) : "",
-                               (prefix) ? prefix : "",
-                               (prefix && prefix_is_nick) ? weechat_config_string (logger_config_file_nick_suffix) : "",
-                               message);
+    ptr_logger_buffer = logger_buffer_search_buffer (buffer);
+    if (ptr_logger_buffer
+        && ptr_logger_buffer->log_enabled
+        && (date > 0)
+        && (line_log_level <= ptr_logger_buffer->log_level))
+    {
+        prefix_ansi = NULL;
+        message_ansi = NULL;
+        color_lines = weechat_config_boolean (logger_config_file_color_lines);
+        if (color_lines)
+        {
+            prefix_ansi = weechat_hook_modifier_exec ("color_encode_ansi",
+                                                      NULL, prefix);
+            message_ansi = weechat_hook_modifier_exec ("color_encode_ansi",
+                                                      NULL, message);
+            ptr_prefix = prefix_ansi;
+            ptr_message = message_ansi;
         }
+        else
+        {
+            ptr_prefix = prefix;
+            ptr_message = message;
+        }
+        buf_time[0] = '\0';
+        date_tmp = localtime (&date);
+        if (date_tmp)
+        {
+            if (strftime (buf_time, sizeof (buf_time) - 1,
+                          weechat_config_string (logger_config_file_time_format),
+                          date_tmp) == 0)
+                buf_time[0] = '\0';
+        }
+
+        logger_write_line (
+            ptr_logger_buffer,
+            "%s\t%s%s%s\t%s%s",
+            buf_time,
+            (ptr_prefix && prefix_is_nick) ? weechat_config_string (logger_config_file_nick_prefix) : "",
+            (ptr_prefix) ? ptr_prefix : "",
+            (ptr_prefix && prefix_is_nick) ? weechat_config_string (logger_config_file_nick_suffix) : "",
+            (color_lines) ? "\x1B[0m" : "",
+            ptr_message);
+
+        if (prefix_ansi)
+            free (prefix_ansi);
+        if (message_ansi)
+            free (message_ansi);
     }
 
     return WEECHAT_RC_OK;
@@ -1287,7 +1187,7 @@ weechat_plugin_init (struct t_weechat_plugin *plugin, int argc, char *argv[])
     weechat_hook_signal ("day_changed",
                          &logger_day_changed_signal_cb, NULL, NULL);
 
-    weechat_hook_print (NULL, NULL, NULL, 1, &logger_print_cb, NULL, NULL);
+    logger_config_color_lines_change (NULL, NULL, NULL);
 
     logger_info_init ();
 
@@ -1304,10 +1204,16 @@ weechat_plugin_end (struct t_weechat_plugin *plugin)
     /* make C compiler happy */
     (void) plugin;
 
-    if (logger_timer)
+    if (logger_hook_print)
     {
-        weechat_unhook (logger_timer);
-        logger_timer = NULL;
+        weechat_unhook (logger_hook_print);
+        logger_hook_print = NULL;
+    }
+
+    if (logger_hook_timer)
+    {
+        weechat_unhook (logger_hook_timer);
+        logger_hook_timer = NULL;
     }
 
     logger_config_write ();
