@@ -411,7 +411,7 @@ relay_config_check_irc_backlog_tags (const void *pointer, void *data,
         return rc;
 
     /* split tags and check them */
-    tags = weechat_string_split (value, ",",
+    tags = weechat_string_split (value, ",", NULL,
                                  WEECHAT_STRING_SPLIT_STRIP_LEFT
                                  | WEECHAT_STRING_SPLIT_STRIP_RIGHT
                                  | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
@@ -462,6 +462,7 @@ relay_config_change_irc_backlog_tags (const void *pointer, void *data,
     items = weechat_string_split (
         weechat_config_string (relay_config_irc_backlog_tags),
         ",",
+        NULL,
         WEECHAT_STRING_SPLIT_STRIP_LEFT
         | WEECHAT_STRING_SPLIT_STRIP_RIGHT
         | WEECHAT_STRING_SPLIT_COLLAPSE_SEPS,
@@ -932,22 +933,6 @@ relay_config_init ()
         N_("text color for client description"),
         NULL, 0, 0, "cyan", NULL, 0,
         NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
-    relay_config_color_status[RELAY_STATUS_CONNECTING] = weechat_config_new_option (
-        relay_config_file, ptr_section,
-        "status_connecting", "color",
-        N_("text color for \"connecting\" status"),
-        NULL, 0, 0, "yellow", NULL, 0,
-        NULL, NULL, NULL,
-        &relay_config_refresh_cb, NULL, NULL,
-        NULL, NULL, NULL);
-    relay_config_color_status[RELAY_STATUS_WAITING_AUTH] = weechat_config_new_option (
-        relay_config_file, ptr_section,
-        "status_waiting_auth", "color",
-        N_("text color for \"waiting authentication\" status"),
-        NULL, 0, 0, "brown", NULL, 0,
-        NULL, NULL, NULL,
-        &relay_config_refresh_cb, NULL, NULL,
-        NULL, NULL, NULL);
     relay_config_color_status[RELAY_STATUS_CONNECTED] = weechat_config_new_option (
         relay_config_file, ptr_section,
         "status_active", "color",
@@ -964,6 +949,14 @@ relay_config_init ()
         NULL, NULL, NULL,
         &relay_config_refresh_cb, NULL, NULL,
         NULL, NULL, NULL);
+    relay_config_color_status[RELAY_STATUS_CONNECTING] = weechat_config_new_option (
+        relay_config_file, ptr_section,
+        "status_connecting", "color",
+        N_("text color for \"connecting\" status"),
+        NULL, 0, 0, "yellow", NULL, 0,
+        NULL, NULL, NULL,
+        &relay_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     relay_config_color_status[RELAY_STATUS_DISCONNECTED] = weechat_config_new_option (
         relay_config_file, ptr_section,
         "status_disconnected", "color",
@@ -972,6 +965,14 @@ relay_config_init ()
         NULL, NULL, NULL,
         &relay_config_refresh_cb, NULL, NULL,
         NULL, NULL, NULL);
+    relay_config_color_status[RELAY_STATUS_WAITING_AUTH] = weechat_config_new_option (
+        relay_config_file, ptr_section,
+        "status_waiting_auth", "color",
+        N_("text color for \"waiting authentication\" status"),
+        NULL, 0, 0, "brown", NULL, 0,
+        NULL, NULL, NULL,
+        &relay_config_refresh_cb, NULL, NULL,
+        NULL, NULL, NULL);
     relay_config_color_text = weechat_config_new_option (
         relay_config_file, ptr_section,
         "text", "color",
