@@ -61,6 +61,7 @@ extern "C"
 /* core */
 IMPORT_TEST_GROUP(Plugins);
 IMPORT_TEST_GROUP(CoreArraylist);
+IMPORT_TEST_GROUP(CoreCalc);
 IMPORT_TEST_GROUP(CoreEval);
 IMPORT_TEST_GROUP(CoreHashtable);
 IMPORT_TEST_GROUP(CoreHdata);
@@ -73,6 +74,7 @@ IMPORT_TEST_GROUP(CoreUrl);
 IMPORT_TEST_GROUP(CoreUtf8);
 IMPORT_TEST_GROUP(CoreUtil);
 /* GUI */
+IMPORT_TEST_GROUP(GuiColor);
 IMPORT_TEST_GROUP(GuiLine);
 IMPORT_TEST_GROUP(GuiNick);
 /* scripts */
