@@ -35,13 +35,13 @@
 
 # check git repository
 ROOT_DIR=$(git rev-parse --show-toplevel)
-if [ -z "${ROOT_DIR}" -o ! -d "${ROOT_DIR}/.git" ]; then
+if [ -z "${ROOT_DIR}" ] || [ ! -d "${ROOT_DIR}/.git" ]; then
     echo "This script must be run from WeeChat git repository."
     exit 1
 fi
 
 # default values
-VERSION="$(${ROOT_DIR}/version.sh devel-full)"
+VERSION="$("${ROOT_DIR}/version.sh" devel-full)"
 TREEISH="HEAD"
 OUTPATH="$(pwd)"
 
@@ -52,19 +52,19 @@ if [ $# -ge 2 ]; then
     TREEISH=$2
 fi
 if [ $# -ge 3 ]; then
-    OUTPATH=$(cd "$3"; pwd)
+    OUTPATH=$(cd "$3" || exit 1; pwd)
 fi
 
-cd "${ROOT_DIR}"
+cd "${ROOT_DIR}" || exit 1
 
 PREFIX="weechat-${VERSION}/"
 FILE="${OUTPATH}/weechat-${VERSION}.tar"
 
 echo "Building package ${FILE}.gz"
-git archive --prefix=${PREFIX} ${TREEISH} | gzip -c >${FILE}.gz
+git archive --prefix="${PREFIX}" "${TREEISH}" | gzip -c >"${FILE}.gz"
 
 echo "Building package ${FILE}.bz2"
-git archive --prefix=${PREFIX} ${TREEISH} | bzip2 -c >${FILE}.bz2
+git archive --prefix="${PREFIX}" "${TREEISH}" | bzip2 -c >"${FILE}.bz2"
 
 echo "Building package ${FILE}.xz"
-git archive --prefix=${PREFIX} ${TREEISH} | xz -c >${FILE}.xz
+git archive --prefix="${PREFIX}" "${TREEISH}" | xz -c >"${FILE}.xz"
